/*
 * MSP430_SWI2C_Master.h
 *
 */

#ifndef MSP430_SWI2C_MASTER_H_
#define MSP430_SWI2C_MASTER_H_


//******************************************************************************
//  MSP430F20xx - I2C Master Transmitter and Receiver via CPU Software (GPIO)
//
//  Description: This code library configures the MSP430 as an I2C master device
//  capable of transmitting and receiving bytes using GPIO pins.  Specific I/O
//  pins can be selected in the corresponding header file.  By default, the same
//  pins that are used by the USI module are selected.
//
//                  Master
//                  MSP430
//             -----------------
//         /|\|              XIN|-
//          | |                 |
//          --|RST          XOUT|-
//            |                 |
//            |                 |
//            |                 |
//            |         SDA/P2.7|-------> [I2C SLAVE SDA]
//            |         SCL/P2.6|-------> [I2C SLAVE SCL]
//
//  Note: Internal pull-ups are NOT used for SDA & SCL [DISABLED]
//
//  R. Wu
//  Texas Instruments Inc.
//  March 2008
//
// gendert fr MSP430G2553 (Port 1) DL9MWE
//******************************************************************************

#include <msp430G2553.h>

#define PxSEL P1SEL // Port selection
#define PxDIR P1DIR // Port direction
#define PxOUT P1OUT // Port output
#define PxIN  P1IN  // Port input

#define SDA   BIT7 // Controls SDA line (pull-up used for logic 1)
#define SCL   BIT6 // Controls SCL line (pull-up used for logic 1)


//#define DELAY_NOP	1	// NOPs in I2C-Steuerung einfgen


void MSP430_SWI2CMST_init(void);

void MSP430_SWI2CMST_readBlock(unsigned char SlaveAddress,
                               unsigned int numBytes, void* RxData);

void MSP430_SWI2CMST_writeBlock(unsigned char SlaveAddress,
                                unsigned int numBytes, void* TxData);

void MSP430_SWI2CMST_repeatedStart(void);    // Send I2C repeated start condition


// interne Funktionen
void MSP430_SWI2CMST_start(void);
void MSP430_SWI2CMST_stop(void);
void MSP430_SWI2CMST_txByte(unsigned char data);
unsigned char MSP430_SWI2CMST_rxByte(void);
void MSP430_SWI2CMST_ack(void);
unsigned int MSP430_SWI2CSLV_ack(void);
void MSP430_SWI2CMST_nack(void);

#endif /* MSP430_SWI2C_MASTER_H_ */
