/*
 * main.c
 * Digital-Analog Conversion mit dem MSP430 und dem MCP4726
 *
 * Beispiel fr die Ausgabe von DAC-Werten via I2C an den 12-Bit DAC MCP4726
 *
 * erzeugt eine Sinus-Schwingung maximaler Frequenz (ca. 7Hz) via MCP726-DAC
 * mit 4*32 Sttzstellen pro Periode werden die Sinus-Werte ausgegeben
 *
 */

#include	"main.h"


void main(void) {

	vCPU_init();
	vLCD_init(16);			// LCD
	vLCD_puts("MCP4726 29.03.13");
	MSP430_SWI2CMST_init();		// Initialisierung der I2C-Software-Schnittstelle als Master

	unsigned int error_code;
	MSP430_SWI2CMST_start();					//Send I2C Start Condition
	MSP430_SWI2CMST_txByte(0x00);				// General Call Address
	error_code = MSP430_SWI2CSLV_ack();			// get slave acknowledge (ACKS)
	MSP430_SWI2CMST_txByte(0x06);				// General Call Reset Command
	error_code = MSP430_SWI2CSLV_ack();			// get slave acknowledge (ACKS)
	MSP430_SWI2CMST_stop();

	while(42) {
		DAC_sinus(300);
		DAC_sinuscontinuous(300);
		MSP430_SWI2CMST_stop();
	}
}


void vCPU_init(void) {
	WDTCTL = WDTPW + WDTHOLD;	// stop watchdog-timer

	DCOCTL = CALDCO_1MHZ;		// interner Oszillator @ 1Mhz
	BCSCTL1 = CALBC1_1MHZ;
	BCSCTL2 = 0;
	BCSCTL3 = 0;
}

// msec Millisekunden lang zhlen
void vdelay_ms(unsigned int msec) {
  volatile unsigned int count;

	while(--msec) {
		count = 86;	// funktioniert bei 1MHz aus dem internen Oszillator DCO
		while(count) {
			--count;
		}
	}
}



// Dummy: um Warnungen zu vermeiden
#pragma vector = PORT1_VECTOR, PORT2_VECTOR, ADC10_VECTOR, USCIAB0TX_VECTOR, USCIAB0RX_VECTOR, TIMER1_A1_VECTOR, TIMER0_A0_VECTOR, TIMER0_A1_VECTOR, TIMER1_A0_VECTOR, WDT_VECTOR, COMPARATORA_VECTOR, NMI_VECTOR
__interrupt void USCIAB0TX_ISR(void)
{
}

// Ende main.c
